pub struct SVGWidget { /* private fields */ }Trait Implementations
Sourceimpl From<SVGWidget> for ImageWidget
Available on crate features bmp or dds or dxt or farbfeld or gif or hdr or ico or jpeg_rayon or jpeg or png or pnm or tga or webp only.
impl From<SVGWidget> for ImageWidget
Available on crate features
bmp or dds or dxt or farbfeld or gif or hdr or ico or jpeg_rayon or jpeg or png or pnm or tga or webp only.Sourcefn from(t: SVGWidget) -> ImageWidget
fn from(t: SVGWidget) -> ImageWidget
Converts to this type from the input type.